@@ -23,6 +23,7 @@ import uuid
 from typing import Literal, Optional
 from urllib.parse import urljoin
 
+import deprecation
 import requests
 from dotenv import dotenv_values
 
@@ -46,7 +47,7 @@ from .namespaces.workspace.table import Table
 
 # TODO this is a manual task, to keep in sync with pyproject.toml
 # could/should be automated to keep in sync
-__version__ = "0.6.0"
+__version__ = "0.7.0"
 
 PERSONAL_API_KEY_LOCATION = "~/.config/xata/key"
 DEFAULT_BASE_URL_DOMAIN = "xata.sh"
@@ -157,6 +158,28 @@ class XataClient:
         """
         return self.headers
 
+    def set_header(self, name: str, value: str):
+        """
+        Set a header value. Every name is lower case and overwrites existing values.
+        This can be useful for some proxies that require certain headers.
+
+        :param name: str
+        :param value: str
+        """
+        self.headers[name.lower().strip()] = value
+
+    def delete_header(self, name: str) -> bool:
+        """
+        Delete a header from the scope. A header name will be lowercased.
+        :param name: str
+        :return bool
+        """
+        name = name.lower().strip()
+        if name not in self.headers:
+            return False
+        del self.headers[name]
+        return True
+
     def get_api_key(self) -> tuple[str, ApiKeyLocation]:
         if os.environ.get("XATA_API_KEY") is not None:
             return os.environ.get("XATA_API_KEY"), "env"
@@ -272,42 +295,6 @@ class XataClient:
         region = parts[1]
         return workspaceId, region, db
 
-    def get(self, urlPath, headers={}, **kwargs):
-        """Send a GET request to the Xata API. This is a wrapper around
-        the `requests` library and accepts the same parameters as the `get`
-        method of the `requests` library.
-        """
-
-        return self.request("GET", urlPath, headers=headers, **kwargs)
-
-    def post(self, urlPath, headers={}, **kwargs):
-        """Send a POST request to the Xata API. This is a wrapper around
-        the `requests` library and accepts the same parameters as the `post`
-        method of the `requests` library.
-        """
-        return self.request("POST", urlPath, headers=headers, **kwargs)
-
-    def put(self, urlPath, headers={}, **kwargs):
-        """Send a PUT request to the Xata API. This is a wrapper around
-        the `requests` library and accepts the same parameters as the `put`
-        method of the `requests` library.
-        """
-        return self.request("PUT", urlPath, headers=headers, **kwargs)
-
-    def delete(self, urlPath, headers={}, **kwargs):
-        """Send a DELETE request to the Xata API. This is a wrapper around
-        the `requests` library and accepts the same parameters as the `delete`
-        method of the `requests` library.
-        """
-        return self.request("DELETE", urlPath, headers=headers, **kwargs)
-
-    def patch(self, urlPath, headers={}, **kwargs):
-        """Send a PATCH request to the Xata API. This is a wrapper around
-        the `requests` library and accepts the same parameters as the `patch`
-        method of the `requests` library.
-        """
-        return self.request("PATCH", urlPath, headers=headers, **kwargs)
-
     def request_body_from_params(
         self,
         columns: list[str] = None,
@@ -346,6 +333,12 @@ class XataClient:
         if branch_name is not None:
             self.branch_name = branch_name
 
+    @deprecation.deprecated(
+        deprecated_in="0.7.0",
+        removed_in="1.0",
+        current_version=__version__,
+        details="client.search_and_filter().queryTable(:table, :body)",
+    )
     def query(
         self,
         table: str,
@@ -356,7 +349,8 @@ class XataClient:
         sort: dict = None,
         page: dict = None,
     ) -> dict:
-        """Query a table.
+        """
+        Please use: client.search_and_filter().queryTable()
 
         :meta public:
         :param table: The name of the table to query.
@@ -370,16 +364,21 @@ class XataClient:
         :param page: A page expression to apply to the query.
         :return: A page of results.
         """
-
         db_name, branch_name = self.db_and_branch_names_from_params(
             db_name, branch_name
         )
         body = self.request_body_from_params(columns, filter, sort, page)
-        result = self.post(
-            f"/db/{db_name}:{branch_name}/tables/{table}/query", json=body
+        result = self.request(
+            "POST", f"/db/{db_name}:{branch_name}/tables/{table}/query", json=body
         )
         return result.json()
 
+    @deprecation.deprecated(
+        deprecated_in="0.7.0",
+        removed_in="1.0",
+        current_version=__version__,
+        details='No direct replacement. Use `{"size": 1}` with client.search_and_filter().queryTable()',
+    )
     def get_first(
         self,
         table: str,
@@ -402,20 +401,25 @@ class XataClient:
         :param sort: A sort expression to apply to the query.
         :return: A record as a dictionary.
         """
-
         page = {"size": 1}
         db_name, branch_name = self.db_and_branch_names_from_params(
             db_name, branch_name
         )
         body = self.request_body_from_params(columns, filter, sort, page)
-        result = self.post(
-            f"/db/{db_name}:{branch_name}/tables/{table}/query", json=body
+        result = self.request(
+            "POST", f"/db/{db_name}:{branch_name}/tables/{table}/query", json=body
         )
         data = result.json()
         if len(data.get("records", [])) == 0:
             return None
         return data.get("records")[0]
 
+    @deprecation.deprecated(
+        deprecated_in="0.7.0",
+        removed_in="1.0",
+        current_version=__version__,
+        details="client.records().getRecord(:table, :id)",
+    )
     def get_by_id(
         self,
         table: str,
@@ -423,10 +427,9 @@ class XataClient:
         db_name: str = None,
         branch_name: str = None,
     ) -> Optional[dict]:
-        """Get a specific record by its ID. Returns None if an record with that ID
-        doesn't exist.
+        """
+        Please use: client.records().getRecord(<id>)
 
-        :meta public:
         :param table: The name of the table to query.
         :param id: The ID of the record to get.
         :param db_name: The name of the database to query. If not provided, the database name
@@ -438,13 +441,21 @@ class XataClient:
         db_name, branch_name = self.db_and_branch_names_from_params(
             db_name, branch_name
         )
-        result = self.get(
-            f"/db/{db_name}:{branch_name}/tables/{table}/data/{id}", expect_codes=[404]
+        result = self.request(
+            "GET",
+            f"/db/{db_name}:{branch_name}/tables/{table}/data/{id}",
+            expect_codes=[404],
         )
         if result.status_code == 404:
             return None
         return result.json()
 
+    @deprecation.deprecated(
+        deprecated_in="0.7.0",
+        removed_in="1.0",
+        current_version=__version__,
+        details="client.records().insertRecord(:table) or client.records().insertRecordWithId(:table, :id)",
+    )
     def create(
         self,
         table: str,
@@ -453,10 +464,11 @@ class XataClient:
         db_name: str = None,
         branch_name: str = None,
     ) -> str:
-        """Create a record in a table. If an ID is not provided, one will be generated.
+        """
+        Please use: client.records().insertRecord(:table) or client.records().insertRecordWithId(:table, :id)
+        Create a record in a table. If an ID is not provided, one will be generated.
         If the ID is provided and a record with that ID already exists, an error is returned.
 
-        :meta public:
         :param table: The name of the table to query.
         :param id: The ID of the record to create. If not provided, one will be generated.
         :param record: The record to create, as dict.
@@ -466,23 +478,29 @@ class XataClient:
                         from the client obejct is used.
         :return: The ID of the created record.
         """
-
         db_name, branch_name = self.db_and_branch_names_from_params(
             db_name, branch_name
         )
         if id is not None:
-            self.put(
+            self.request(
+                "PUT",
                 f"/db/{db_name}:{branch_name}/tables/{table}/data/{id}",
                 params=dict(createOnly=True),
                 json=record,
             )
             return id
 
-        result = self.post(
-            f"/db/{db_name}:{branch_name}/tables/{table}/data", json=record
+        result = self.request(
+            "POST", f"/db/{db_name}:{branch_name}/tables/{table}/data", json=record
         )
         return result.json()["id"]
 
+    @deprecation.deprecated(
+        deprecated_in="0.7.0",
+        removed_in="1.0",
+        current_version=__version__,
+        details="client.records().upsertRecordWithID(:table, :id)",
+    )
     def create_or_update(
         self,
         table: str,
@@ -491,7 +509,8 @@ class XataClient:
         db_name: str = None,
         branch_name: str = None,
     ) -> str:
-        """Create or updated a record in a table. If a record with the same id already
+        """
+        Create or updated a record in a table. If a record with the same id already
         exists, it will be updated. Only the provided columns in record are replaced, is
         a column is not present explicitely in record, it is not updated.
 
@@ -508,11 +527,17 @@ class XataClient:
         db_name, branch_name = self.db_and_branch_names_from_params(
             db_name, branch_name
         )
-        result = self.post(
-            f"/db/{db_name}:{branch_name}/tables/{table}/data/{id}", json=record
+        result = self.request(
+            "POST", f"/db/{db_name}:{branch_name}/tables/{table}/data/{id}", json=record
         )
         return result.json()["id"]
 
+    @deprecation.deprecated(
+        deprecated_in="0.7.0",
+        removed_in="1.0",
+        current_version=__version__,
+        details="client.records().insertRecordWithID(:table, :id)",
+    )
     def create_or_replace(
         self,
         table: str,
@@ -537,11 +562,17 @@ class XataClient:
         db_name, branch_name = self.db_and_branch_names_from_params(
             db_name, branch_name
         )
-        result = self.put(
-            f"/db/{db_name}:{branch_name}/tables/{table}/data/{id}", json=record
+        result = self.request(
+            "PUT", f"/db/{db_name}:{branch_name}/tables/{table}/data/{id}", json=record
         )
         return result.json()["id"]
 
+    @deprecation.deprecated(
+        deprecated_in="0.7.0",
+        removed_in="1.0",
+        current_version=__version__,
+        details="client.records().updateRecordWithID(:table, :id)",
+    )
     def update(
         self,
         table: str,
@@ -573,7 +604,8 @@ class XataClient:
         params = {"columns": "*"}
         if ifVersion is not None:
             params["ifVersion"] = str(ifVersion)
-        result = self.patch(
+        result = self.request(
+            "PATCH",
             f"/db/{db_name}:{branch_name}/tables/{table}/data/{id}",
             params=params,
             json=record,
@@ -587,6 +619,12 @@ class XataClient:
             return None
         return result.json()
 
+    @deprecation.deprecated(
+        deprecated_in="0.7.0",
+        removed_in="1.0",
+        current_version=__version__,
+        details="client.records().deleteRecord(:table, :id)",
+    )
     def delete_record(
         self, table: str, id: str, db_name: str = None, branch_name: str = None
     ) -> Optional[dict]:
@@ -606,7 +644,8 @@ class XataClient:
             db_name, branch_name
         )
         params = {"columns": "*"}
-        result = self.delete(
+        result = self.request(
+            "DELETE",
             f"/db/{db_name}:{branch_name}/tables/{table}/data/{id}",
             params=params,
             expect_codes=[404],
@@ -615,6 +654,12 @@ class XataClient:
             raise RecordNotFoundException(id)
         return result.json()
 
+    @deprecation.deprecated(
+        deprecated_in="0.7.0",
+        removed_in="1.0",
+        current_version=__version__,
+        details="client.search_and_filter().searchBranch(:payload)",
+    )
     def search(
         self,
         query: str,
@@ -640,7 +685,8 @@ class XataClient:
             db_name, branch_name
         )
         query_params["query"] = query.strip()
-        result = self.post(
+        result = self.request(
+            "POST",
             f"/db/{db_name}:{branch_name}/search",
             json=query_params,
             expect_codes=[200, 400, 403, 404, 500],
@@ -650,6 +696,12 @@ class XataClient:
             raise BadRequestException(result.status_code, result.json()["message"])
         return result.json()
 
+    @deprecation.deprecated(
+        deprecated_in="0.7.0",
+        removed_in="1.0",
+        current_version=__version__,
+        details="client.search_and_filter().searchTable(:payload)",
+    )
     def search_table(
         self,
         table_name: str,
@@ -675,7 +727,8 @@ class XataClient:
             db_name, branch_name
         )
         query_params["query"] = query.strip()
-        result = self.post(
+        result = self.request(
+            "POST",
             f"/db/{db_name}:{branch_name}/tables/{table_name}/search",
             json=query_params,
             expect_codes=[200, 400, 403, 404, 500],
