@@ -37,8 +37,18 @@ class Invites(Namespace):
     def inviteWorkspaceMember(self, workspace_id: str, payload: dict) -> Response:
         """
         Invite some user to join the workspace with the given role
+
         Path: /workspaces/{workspace_id}/invites
         Method: POST
+        Response status codes:
+        - 201: Created
+        - 400: Bad Request
+        - 401: Authentication Error
+        - 403: Authentication Error
+        - 404: Example response
+        - 409: Example response
+        - 5XX: Unexpected Error
+        Response: application/json
 
         :param workspace_id: str Workspace ID
         :param payload: dict content
@@ -55,8 +65,16 @@ class Invites(Namespace):
         """
         This operation provides a way to cancel invites by deleting them.  Already accepted
         invites cannot be deleted.
+
         Path: /workspaces/{workspace_id}/invites/{invite_id}
         Method: DELETE
+        Response status codes:
+        - 204: No Content
+        - 400: Bad Request
+        - 401: Authentication Error
+        - 403: Authentication Error
+        - 404: Example response
+        - 5XX: Unexpected Error
 
         :param workspace_id: str Workspace ID
         :param invite_id: str Invite identifier
@@ -73,8 +91,18 @@ class Invites(Namespace):
         This operation provides a way to update an existing invite.  Updates are performed in-
         place; they do not change the invite link, the expiry time, nor do they re-notify the
         recipient of the invite.
+
         Path: /workspaces/{workspace_id}/invites/{invite_id}
         Method: PATCH
+        Response status codes:
+        - 200: Updated successfully.
+        - 400: Bad Request
+        - 401: Authentication Error
+        - 403: Authentication Error
+        - 404: Example response
+        - 422: Example response
+        - 5XX: Unexpected Error
+        Response: application/json
 
         :param workspace_id: str Workspace ID
         :param invite_id: str Invite identifier
@@ -92,8 +120,16 @@ class Invites(Namespace):
         """
         Accept the invitation to join a workspace.  If the operation succeeds the user will be a
         member of the workspace
+
         Path: /workspaces/{workspace_id}/invites/{invite_key}/accept
         Method: POST
+        Response status codes:
+        - 204: OK
+        - 400: Bad Request
+        - 401: Authentication Error
+        - 403: Authentication Error
+        - 404: Example response
+        - 5XX: Unexpected Error
 
         :param workspace_id: str Workspace ID
         :param invite_key: str Invite Key (secret) for the invited user
@@ -109,8 +145,16 @@ class Invites(Namespace):
         """
         This operation provides a way to resend an Invite notification.  Invite notifications can
         only be sent for Invites not yet accepted.
+
         Path: /workspaces/{workspace_id}/invites/{invite_id}/resend
         Method: POST
+        Response status codes:
+        - 204: OK
+        - 400: Bad Request
+        - 401: Authentication Error
+        - 403: Authentication Error
+        - 404: Example response
+        - 5XX: Unexpected Error
 
         :param workspace_id: str Workspace ID
         :param invite_id: str Invite identifier
